from . import dist as dist
from . import formal as formal
from .max import max
from .mean import mean
from .min import min
from .sum import sum
from .stddev import stddev
from .variance import variance
